
Summary:       Official JDBC driver for MySQL
Name:          mysql-connector-java
Epoch:         1
Version:       9.2.0
Release:       %mkrel 1
Group:         Development/Java
License:       GPLv2 with exceptions
URL:           https://dev.mysql.com/downloads/connector/j/
Source0:       %{name}-%{version}-nojars.tar.xz

# Mysql has a mirror redirector for its downloads
# You can get this tarball by following a link from:
# https://dev.mysql.com/get/Downloads/Connector-J/mysql-connector-j-%%{version}.tar.gz
#
# OR
# https://github.com/mysql/mysql-connector-j/archive/%%{version}.tar.gz
# Following prebuilt jars and sources have been removed from the tarball:
#
# %%{name}-%%{version}-bin.jar
# lib/c3p0-0.9.1-pre6.jar
# lib/c3p0-0.9.1-pre6.src.zip
# lib/jboss-common-jdbc-wrapper.jar
# lib/jboss-common-jdbc-wrapper-src.jar
# lib/protobuf-java-3.6.1.jar
# lib/slf4j-api-1.6.1.jar
#
# See https://bugs.mysql.com/bug.php?id=28512 for details.

# To make it easier a script generate-tarball.sh has been created:
# ./generate-tarball.sh version
# will create a new tarball compressed with xz and without those jar files.
Source1:       generate-tarball.sh

Patch1:        remove-coverage-test.patch
Patch2:        java-11-migration.patch
Patch3:        remove-authentication-plugin.patch
Patch4:        remove-StatementsTest.patch
Patch5:        %{name}-remove-opentelemetry-support.patch

BuildArch:     noarch

BuildRequires: ant >= 1.6.0
BuildRequires: ant-junit
BuildRequires: apache-commons-logging
BuildRequires: git
BuildRequires: javassist
BuildRequires: java-devel >= 1:1.6.0
BuildRequires: javapackages-local
BuildRequires: junit5
BuildRequires: protobuf-java
BuildRequires: slf4j
BuildRequires: java-21-openjdk-devel

Requires:      slf4j
Requires:      java

%description
MySQL Connector/J is a native Java driver that converts JDBC (Java Database
Connectivity) calls into the network protocol used by the MySQL database.
It lets developers working with the Java programming language easily build
programs and applets that interact with MySQL and connect all corporate
data, even in a heterogeneous environment. MySQL Connector/J is a Type
IV JDBC driver and has a complete JDBC feature set that supports the
capabilities of MySQL.

%prep
%setup -q -n mysql-connector-j-%{version}

# fix line endings
for file in README README.md; do
 sed -i.orig 's|\r||g' $file
 touch -r $file.orig $file
 rm $file.orig
done

%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

# remove OpenTelemetry support
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetryHandler.java
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetrySpan.java
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetryScope.java

%build

# We need both JDK1.5 (for JDBC3.0; appointed by $JAVA_HOME) and JDK1.6 (for JDBC4.0; appointed in the build.xml)
export CLASSPATH=$(build-classpath jdbc-stdext junit slf4j commons-logging.jar)

# We currently need to disable jboss integration because of missing jboss-common-jdbc-wrapper.jar (built from sources).
# See BZ#480154 and BZ#471915 for details.
rm -rf src/main/user-impl/java/com/mysql/cj/jdbc/integration/jboss
rm src/test/java/testsuite/regression/ConnectionRegressionTest.java
rm src/test/java/testsuite/regression/DataSourceRegressionTest.java
rm src/test/java/testsuite/simple/StatementsTest.java

ant -Dcom.mysql.cj.build.jdk=/usr/lib/jvm/java-21-openjdk \
    -Dcom.mysql.cj.extra.libs=%{_javadir} \
    -Dcom.mysql.cj.build.driver.extendedName=mysql-connector-j \
    -Dcom.mysql.cj.build.driver.version.full=%{version} \
    test build

# Provide alias for old name
%mvn_alias com.mysql:mysql-connector-j mysql:mysql-connector-java

%install
# Install the Maven build information
%mvn_file com.mysql:mysql-connector-j mysql-connector-j
%mvn_artifact build/mysql-connector-j-%{version}/pom.xml build/mysql-connector-j-%{version}/mysql-connector-j-%{version}.jar
%mvn_install

%files -f .mfiles
%doc CHANGES README README.md
%license LICENSE




%changelog
* Mon Mar 17 2025 daviddavid <daviddavid> 1:9.2.0-1.mga10
+ Revision: 2165584
- new version: 9.2.0

* Mon May 27 2024 ns80 <ns80> 1:8.0.33-2.mga10
+ Revision: 2068284
- rebuild for java 21

* Wed Apr 19 2023 daviddavid <daviddavid> 1:8.0.33-1.mga9
+ Revision: 1953641
- new version: 8.0.33, fixes CVE-2023-21971 (mga#29567#c5)

* Wed Jan 25 2023 daviddavid <daviddavid> 1:8.0.32-1.mga9
+ Revision: 1936176
- rebase to version 8.0.32
- change ant target from "dist" to "build", as it's been renamed
- As Oracle renamed the package from "mysql:mysql-connector-java" to
  "com.mysql:mysql-connector-j", we are "providing" both names for now,
  but the package has to be renamed to accommodate the change because
  the old name will be deprecated at some point in the future without
  further notice.

* Thu Dec 08 2022 daviddavid <daviddavid> 1:8.0.30-1.mga9
+ Revision: 1919599
- rebase to version 8.0.30
- build with jdk17
- bz#2110975
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Oct 26 2021 neoclust <neoclust> 1:8.0.27-1.mga9
+ Revision: 1752951
- New version 8.0.27: Fixes CVE-2021-2471 (mga#29567)

* Mon Mar 01 2021 daviddavid <daviddavid> 1:8.0.23-1.mga9
+ Revision: 1694812
- rebase to version 8.0.23

* Fri Jan 15 2021 neoclust <neoclust> 1:8.0.22-2.mga8
+ Revision: 1671861
- Remove ant-contrib deps

* Wed Oct 21 2020 daviddavid <daviddavid> 1:8.0.22-1.mga8
+ Revision: 1637895
- rebase to version 8.0.22

* Thu Sep 03 2020 daviddavid <daviddavid> 1:8.0.21-1.mga8
+ Revision: 1621228
- update to version 8.0.21

* Sun May 31 2020 neoclust <neoclust> 1:8.0.20-1.mga8
+ Revision: 1589186
- New version 8.0.20

* Sun May 31 2020 neoclust <neoclust> 1:8.0.16-4.mga8
+ Revision: 1589151
- removed jta dependency
- removed c3p0 dependency

* Sun Feb 16 2020 umeabot <umeabot> 1:8.0.16-3.mga8
+ Revision: 1534278
- Mageia 8 Mass Rebuild

* Wed Oct 02 2019 daviddavid <daviddavid> 1:8.0.16-2.mga8
+ Revision: 1448853
- removed hibernate dependency

* Mon May 06 2019 daviddavid <daviddavid> 1:8.0.16-1.mga7
+ Revision: 1396525
- new version: 8.0.16, fixes CVE-2019-2692 (mga#23720)

* Fri Feb 22 2019 daviddavid <daviddavid> 1:8.0.15-1.mga7
+ Revision: 1369318
- new version: 8.0.15

* Thu Nov 01 2018 daviddavid <daviddavid> 1:8.0.13-1.mga7
+ Revision: 1327190
- new version: 8.0.13

* Thu Sep 20 2018 umeabot <umeabot> 1:8.0.12-2.mga7
+ Revision: 1280071
- Mageia 7 Mass Rebuild

* Thu Aug 30 2018 daviddavid <daviddavid> 1:8.0.12-1.mga7
+ Revision: 1255756
- new version: 8.0.12 (sync with fc29)

* Sat Oct 07 2017 daviddavid <daviddavid> 1:5.1.42-1.mga7
+ Revision: 1169987
- new version: 5.1.42 - Fixes CVE-2017-3523, CVE-2017-3586, and CVE-2017-3589 (mga#20731)

* Sat Oct 07 2017 daviddavid <daviddavid> 1:5.1.38-1.mga7
+ Revision: 1169832
- update to 5.1.38 (sync with fc27)
- use upstream git tarball
- fix jdbc-4.1 patch
+ neoclust <neoclust>
- Second rebuild of the java stack
- First rebuild of the java stack
- sync package mysql-connector-java with fedora

* Thu Feb 18 2016 umeabot <umeabot> 1:5.1.35-2.mga6
+ Revision: 965613
- Mageia 6 Mass Rebuild

* Sun Jun 14 2015 luigiwalser <luigiwalser> 1:5.1.35-1.mga5
+ Revision: 823145
- update to 5.1.35 and sync with opensuse to fix CVE-2015-2575

* Sat Jan 17 2015 daviddavid <daviddavid> 1:5.1.26-4.mga5
+ Revision: 811175
- use .mfiles generated during build
- update Requires

* Wed Oct 15 2014 umeabot <umeabot> 1:5.1.26-3.mga5
+ Revision: 745568
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:5.1.26-2.mga5
+ Revision: 682724
- Mageia 5 Mass Rebuild

* Mon Dec 30 2013 dmorgan <dmorgan> 1:5.1.26-1.mga4
+ Revision: 563230
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu Jan 17 2013 umeabot <umeabot> 1:5.1.22-2.mga3
+ Revision: 389214
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ dmorgan <dmorgan>
- New version
- Build with java7
- Build with java7

* Thu Dec 15 2011 gil <gil> 1:5.1.18-1.mga2
+ Revision: 181722
- update to 5.1.18
  enable gcj support
  replace log4j with slf4j

* Sun Apr 17 2011 stormi <stormi> 1:5.1.14-2.mga1
+ Revision: 87441
- fix RPM group

* Fri Jan 28 2011 dmorgan <dmorgan> 1:5.1.14-1.mga1
+ Revision: 42987
- Fix %%doc
- Fix requires
- Update to 5.1.14
- Remove fc macro
- imported package mysql-connector-java


* Fri Feb 19 2010 Miloš Jakubíček <xjakub@fi.muni.cz> - 1:5.1.12-1
- Update to 5.1.12

* Fri Jan 29 2010 Milos Jakubicek <xjakub@fi.muni.cz> 1:5.1.11-1
- Update to 5.1.11

* Thu Jan 21 2010 Tom Lane <tgl@redhat.com> 1:5.1.8-3
- Clean up rpmlint complaints (/usr/lib/ references, old provides/obsoletes,
  tab usage)

* Fri Dec  4 2009 Mary Ellen Foster <mefoster at gmail.com> - 1:5.1.8-2
- Add Maven POM and depmap fragment

* Tue Aug 26 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 1:5.1.8-1
- Update to 5.1.8 (resolves BZ#480154) with jboss integration disabled.
- Added BR: java-1.6.0-openjdk-devel, java-1.5.0-gcj-devel, jakarta-commons-logging
- Minor spec file updates: %%global instead of %%define, tabs instead of spaces
- Dropped unnecessary patch-build.xml and mysql-connector-java-noSunAppletSecurity.patch

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:3.1.12-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:3.1.12-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Aug 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1:3.1.12-6
- fix license tag

* Fri Apr 04 2008 Andrew Overholt <overholt@redhat.com> 1:3.1.12-5
- Rebuild for rhbz #234286.

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1:3.1.12-4
- Autorebuild for GCC 4.3

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 1:3.1.12-3
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Thu Sep 21 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-2
- Remove jpp string from release.

* Fri Sep 08 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-1jpp_5fc
- Add dist tag.

* Thu Sep 07 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-1jpp_4fc
- Fix indentation of preamble.
- Fix version and epoch of jta Requires.
- Fix Group from Development/Libraries to System Environment/Libraries.

* Wed Sep 06 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-1jpp_3fc
- Remove duplicate readme files.
- Remove binary jars from distributed tarball, since they have no source
  attached to them, and are in violation of the LGPL.
- Change jta BR to 1.0 from 1.0.1 since geronimo-specs-compat is 1.0.
- Remove unneccessary 0 epoch from BRs.

* Thu Jul 20 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-1jpp_2fc
- Fix line endings.
- Change Group to standard Development/Java.

* Thu Jun 1 2006 Igor Foox <ifoox@redhat.com> 1:3.1.12-1jpp_1fc
- Natively compile
- Add mysql-connector-java-noSunAppletSecurity.patch to take out references
to sun classes
- Change BuildRoot to what Extras expects

* Thu Feb 2 2006 Jason Corley <jason.corley@gmail.com> 1:3.1.12-1jpp
- 3.1.12
- add some more docs from the tarball
- correct url
- remove vendor and distribution, should be defined in ~/.rpmmacros instead

* Sun May 14 2005 Jason Corley <jason.corley@gmail.com> 1:3.1.8-0.a.1jpp
- 3.1.8a

* Sun Feb 13 2005 Jason Corley <jason.corley@gmail.com> 1:3.1.6-1jpp
- Update to 3.1.6 now that it's considered stable

* Sat Feb 12 2005 Jason Corley <jason.corley@gmail.com> 1:3.0.16-1jpp
- Update to 3.0.16

* Mon Aug 23 2004 Fernando Nasser <fnasser@redhat.com> 1:3.0.14-1jpp
- Update to 3.0.14
- Rebuilt with Ant 1.6.2

* Wed Mar 24 2004 Kaj J. Niemi <kajtzu@fi.basen.net> 1:3.0.11-1jpp
- Bumped epoch, back to a "stable" release

* Fri Mar 19 2004 Kaj J. Niemi <kajtzu@fi.basen.net> 0:3.1.1-1jpp
- 3.1.1, supports stored procedures and SAVEPOINTs among other things.
- Tidy .spec file: nicer description and don't own %%{_javadir}

* Wed Jan 21 2004 David Walluck <david@anti-microsoft.org> 0:3.0.10-1jpp
- 3.0.10
- change group

* Wed Oct 05 2003 Henri Gomez <hgomez@users.sourceforge.net>  0:3.0.9-1jpp
- mysql-connector-j 3.0.9

* Mon Jul 07 2003 Henri Gomez <hgomez@users.sourceforge.net> 3.0.8.2jpp
- mysql-connector-j 3.0.8
- jar goes back in /usr/share/java

* Sun May 11 2003 David Walluck <david@anti-microsoft.org> 0:3.0.6-2jpp
- update for JPackage 1.5

* Tue Mar 25 2003 Nicolas Mailhot <Nicolas.Mailhot (at) JPackage.org> 3.0.6-1jpp
- For jpackage-utils 1.5
- New project name
- Requires java >= 1.4.1

* Thu Jun 06 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0.14.1jpp
- mm.mysql 2.0.14

* Tue May 07 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0.13.1jpp
- mm.mysql 2.0.13

* Tue Mar 26 2002 Henri Gomez <hgomez@users.sourceforge.net> 2.0.11.2jpp
- correct changelog

* Mon Feb 04 2002 Henri Gomez <hgomez@users.sourceforge.net>
- mm.mysql 2.0.11

* Thu Jan 17 2002 Henri Gomez <hgomez@users.sourceforge.net>
- mm.mysql 2.0.8
- seriously patch build.xml to make it compile on Linux boxes
  with both JDK 1.2/1.3 and 1.1
- added javadoc generation to build.xml
- changed manual to javadoc package

* Tue Feb 06 2001 Henri Gomez <hgomez@users.sourceforge.net>
- mm.mysql 2.0.4
- Fixes to getDecimal to fix decimal place wrong bug

* Mon Jan 15 2001 Henri Gomez <hgomez@users.sourceforge.net>
- Initial release mm.mysql 2.0.3
- detect jdbc-2.0 extension jar (javax.sql) and if present
  also build MysqlDataSource and MysqlDataSourceFactory
- build with IBM JDK 1.3.0 (cx130-20001114) and jikes 1.12
- build CLASSPATH=/usr/share/java/jdbc2_0-stdext.jar
